# Contents:

pheflux: fenotipo / flujo metabolico

- pheflux.py: Pheflux computational implementation in Python3.
- examples: Folder containing examples running pheflux for unicelular organisms and human cells.
- paper_figures: Jupyter notebooks used to generate the figures of the paper.
